require 'singleton'
require 'cocoapods-whitelist/model/allowed_dependency'

class WhitelistResolver
    include Singleton
    attr_accessor :whitelist
    attr_accessor :whitelist_loaded
    attr_accessor :whitelist_url

    def config 
        @whitelist ||= []
    end 

    def initialize()
        @whitelist_url = DEFAULT_WHITELIST_URL
        load_whitelist()
    end

    def get_whitelist(whitelist_url = DEFAULT_WHITELIST_URL)
        @whitelist_loaded = @whitelist_url == whitelist_url
        @whitelist_url = whitelist_url

        load_whitelist() unless @whitelist_loaded
        return @whitelist
    end

    def load_whitelist
        begin
            open(@whitelist_url) { |io|
                buffer = io.read
                @whitelist = parse_whitelist(buffer)
                @whitelist_loaded = true
            }
        rescue OpenURI::HTTPError => e
            status = e.io.status.join(' ')
            raise "Failed to fetch whitelist from '#{@whitelist_url}'.\n Error: #{status}"
        end
    end

    def parse_whitelist(raw_whitelist)
        json = JSON.parse(raw_whitelist)
        return json["whitelist"].map { |dependencyJson|
            AllowedDependency.new(dependencyJson["name"], dependencyJson["version"], dependencyJson["expire"], dependencyJson["source"], dependencyJson["target"])
        }
    end
end