require_relative '../validator/source_validator'
require_relative '../helpers/source_helper'
require_relative '../model/sources'

module Pod
    class Resolver
        alias original_search_for search_for
        ## Filter specifications
        def search_for(dependency)
            ## If you have a dependency problem, then no specification is returned from :search_for
            specifications = original_search_for(dependency)

            valid_specifications = validate_dependency(dependency,specifications)
            if valid_specifications.size != specifications.size 
                Pod::UI.puts "WARNING: More than 1 specification for dependency #{dependency.root_name} was found.".yellow
                Pod::UI.puts "WARNING: Check if this could be a potencial dependency inyection".red
            end

            valid_specifications
        end

        # Returns the valids specifications for a given dependency
        # Params:
        # +dependency+:: dependency to be validated
        # +specifications+:: potencial unsecure specs
        # @returs the result of the validation
        def validate_dependency(dependency, specifications)
            private_sources = get_private_sources()
            SourceHelper.instance.setup(sources, private_sources) unless SourceHelper.instance.is_filled
            validator = SourceValidator.new(SourceHelper.instance.specs, private_sources)
            return validator.filter_dependency(dependency.root_name, specifications) 
        end
    end
end